OutlawConfig

Struct OutlawConfig 

pub(super) struct OutlawConfig {
Show 32 fields pub restless_blades_cdr_ms_per_cp: u32, pub restless_blades_rtb_bonus: f64, pub ruthlessness_cp_per_cp: f64, pub quick_draw_cp: f64, pub hidden_opportunity_mod: f64, pub has_audacity: bool, pub has_loaded_dice: bool, pub has_improved_adrenaline_rush: bool, pub has_deadly_pursuit: bool, pub sleight_of_hand_chance: f64, pub deft_maneuvers_cp: f64, pub blade_flurry_targets: u8, pub fan_the_hammer_extra: u32, pub fan_the_hammer_mult: f64, pub hand_of_fate_cp: f64, pub coin_matching_odds: f64, pub deal_fate_cp: f64, pub delivered_doom_mult: f64, pub delivered_doom_cp: f64, pub ace_up_chance_per_cp: f64, pub ace_up_cp_gain: f64, pub summarily_dispatched_mult: f64, pub summarily_dispatched_btte_bonus: f64, pub scoundrel_cp_threshold: f64, pub palmed_bullets_chance_per_cp: f64, pub gravedigger_cp: f64, pub lucky_coin_flips: i32, pub lucky_coin_odds: f64, pub has_edge_case: bool, pub rush_energy: f64, pub rush_energy_edge: f64, pub controlled_chaos_streak: i32,
}

Fields

restless_blades_cdr_ms_per_cp: u32

Restless Blades CDR per combo point.

restless_blades_rtb_bonus: f64

Jackpot Restless Blades bonus.

ruthlessness_cp_per_cp: f64

Ruthlessness points per resource.

quick_draw_cp: f64

Quick Draw energize.

hidden_opportunity_mod: f64

Hidden Opportunity damage fraction.

has_audacity: bool

Audacity selection.

has_loaded_dice: bool

Loaded Dice selection.

has_improved_adrenaline_rush: bool

Improved Adrenaline Rush selection.

has_deadly_pursuit: bool

Deadly Pursuit selection.

sleight_of_hand_chance: f64

Sleight of Hand proc chance.

deft_maneuvers_cp: f64

Deft Maneuvers fixed combo-point gain.

blade_flurry_targets: u8

Blade Flurry target cap.

fan_the_hammer_extra: u32

Fan the Hammer extra casts.

fan_the_hammer_mult: f64

Fan the Hammer damage reduction.

hand_of_fate_cp: f64

Hand of Fate combo-point gain.

coin_matching_odds: f64

Fatebound matching odds composed from Mean Streak and Destiny Defined.

deal_fate_cp: f64

Deal Fate combo-point gain.

delivered_doom_mult: f64

Delivered Doom finisher damage multiplier.

delivered_doom_cp: f64

Delivered Doom combo-point threshold.

ace_up_chance_per_cp: f64

Rank-scaled Ace Up Your Sleeve chance per combo point.

ace_up_cp_gain: f64

Ace Up Your Sleeve energize.

summarily_dispatched_mult: f64

Summarily Dispatched Dispatch damage.

summarily_dispatched_btte_bonus: f64

Between the Eyes magnifies Summarily Dispatched while it is up.

scoundrel_cp_threshold: f64

Gravedigger tier 2 Scoundrel threshold.

palmed_bullets_chance_per_cp: f64

Gravedigger tier 3 Palmed Bullets chance.

gravedigger_cp: f64

Gravedigger energize.

lucky_coin_flips: i32

Lucky Coin flip count.

lucky_coin_odds: f64

Lucky Coin matching-odds bonus.

has_edge_case: bool

Edge Case selection.

rush_energy: f64

Rush to the Inevitable energy.

rush_energy_edge: f64

Rush to the Inevitable Edge Case energy.

controlled_chaos_streak: i32

Controlled Chaos streak length.